Class: Jekyll::Assets::Hook::Point

Inherits:
Object
  • Object
show all
Defined in:
lib/jekyll/assets/hook.rb

Overview

--

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(priority, &block) ⇒ Point

--

A hook point only holds data for later, it really serves no other purpose for now, other than to make live easier for handling hooks and their sorting, later in stream.



24
25
26
# File 'lib/jekyll/assets/hook.rb', line 24

def initialize(priority, &block)
  @priority, @block = priority, block
end

Instance Attribute Details

#blockObject

Returns the value of attribute block.



16
17
18
# File 'lib/jekyll/assets/hook.rb', line 16

def block
  @block
end

#priorityObject

Returns the value of attribute priority.



16
17
18
# File 'lib/jekyll/assets/hook.rb', line 16

def priority
  @priority
end